* # Adobe Analytics for Team ACT v0.0.2

This module has been built to provide a better environment specifically for adobe analysts in Team ACT.

## New in 0.0.2

* retrieve\_by\_RS\_parallel 함수 추가

     ⦁ 'ThreadPoolExecutor'를 활용한 동시 실행 구조를 적용

     ⦁ 사용 방식에는 변경이 없으며, 성능 측면 및 처리 효율 향상에서 개선

* 'max\_retries' 기능 수정

     ⦁ "oberon\_client\_http\_error" 감지하도록 수정

## New in 0.0.1.60

* pandas, sqlalchemy version upgrade에 따른 update

## New in 0.0.1.59

* retrieve\_by\_RS\_breakdownTotal / retrieve\_SecondLevelTotal 함수 추가

  * Dimension과 Breakdown 값을 동시에 추출 가능

* 'No data returned \& lastPage is False'로 인한 무한 루프 해결

  * 데이터 추출시, 수치가 없으면 다음 행으로 넘어도록 코드 수정

* retrieve\_SecondLevel, retrieve\_FirstLevel에 limit 기능 추가 및 수정

  * retrieve\_SecondLevel / retrieve\_SecondLevelTotal에 limit1, limit2로 1st Dimension과 breakdown의 limit을 각각 지정할 수 있도록 기능 추가
  * retrieve\_FirstLevel에 limit 기능 수정

* MST Site Code Filter 203개로 축소

  * \[Site Code] 103개 사이트 - Evar 세그먼트 기준 APP포함 총 206의 site code만 포함
  * \[site code], \[site code]-app

## New in 0.0.1.58

* 'max\_retries' 기능 추가 (default = 5)

  * AttributeError, ConnectionError 등으로 인해 추출이 되지 않을 때, 'max\_retries' 만큼 재추출하도록 하는 기능을 추가

## New in 0.0.1.57

* Site Code Filter에 Site Code 추가

  * \[v.0.0.1.57] 이전 : \[site code], \[site code]-smb 총 137개
  * \[v.0.0.1.57] 이후 : \[site code]-app, \[site code]-epp, \[site code]-epp-app, \[site code]-smb-app 추가 총 636개

* retrieve\_by\_RS \& retrieve\_by\_RS\_breakdown에서 MST 데이터 추출 가능
* 'extra1' 기능 추가

  * 데이터 추출 시 구분자로 사용되던 'extra'뒤에 'extra1'을 추가하여 구분자를 2개까지 활용 가능

* 데이터 추출시 사용 되던 Loop 순서 변경

  * Date > RS에서 RS > Date로 변경

## New in 0.0.1.53

* RS INPUT 변수에 UK-VRS 추가

  * uk > UK VRS
  * uk\_epp > UK RS

## New in 0.0.1.52

* limit 기능 추가
* retrieve\_by\_RS\_breakdown 함수에 limit1, limit2 기능 추가
* retrieve\_by\_RS 함수에 limit 기능 추가
* limit 변수 순서 변경 및 limit option화 (limit을 필수 변수에서 선택 변수로 변경, 미지정시 모든 데이터 추출)
* Encoding error 수정
* 특수문자 데이터 저장으로 인한 오류 수정
* Semiconductor RS 추가 (7개)
* ds-global, ds-cn, ds-us, ds-kr, ds-emea, ds-jp, ds-total



## New in 0.0.1.48

* Api 동시 추출 기능 추가

  * sqlalchemy 패키지 사용

More functionalities will be added in sooner time.

